# Vim Docs - Markdown Documentation Platform

A Flask-based documentation platform with Vim editing capabilities, designed for developers and tech enthusiasts who prefer keyboard-centric navigation and editing.

## Features

- **Vim Editing**: Full Vim keybindings for editing your documents
- **Markdown Support**: GitHub-style markdown rendering with support for tables, code blocks, and alert blocks
- **Real-time Preview**: Split-screen editing with synchronized scrolling between editor and preview
- **Organization**: Hierarchical categories with customizable icons
- **Tags**: Tag-based document organization and filtering
- **Export**: Export your documents as markdown files
- **Keyboard Shortcuts**: Navigate the app efficiently with Vim-inspired keyboard shortcuts

## Setup Instructions

### Prerequisites

- Python 3.7+
- pip (Python package manager)

### Installation

1. Clone this repository:
   ```
   git clone https://github.com/yourusername/vim-docs.git
   cd vim-docs
   ```

2. Create and activate a virtual environment (recommended):
   ```
   python -m venv venv
   source venv/bin/activate  # On Windows: venv\Scripts\activate
   ```

3. Install dependencies:
   ```
   pip install -r requirements.txt
   ```

4. Initialize the database:
   ```
   python app.py
   ```

5. Access the application:
   Open your browser and navigate to `http://localhost:5000`

## Keyboard Shortcuts

- `Ctrl+E`: Edit the current document (when viewing)
- `n`: Create a new document
- `/`: Focus the search box (if available)
- `g h`: Go to the home page

## Within the Editor

- Standard Vim keybindings (`h`, `j`, `k`, `l` for navigation, etc.)
- `Ctrl+S`: Save the current document

## Alert Blocks

You can create GitHub-style alert blocks in your markdown:

```
> [!INFO] 
> This is an information alert.

> [!WARNING]
> This is a warning alert.

> [!DANGER]
> This is a danger alert.
```

## License

MIT License

## Credits

- CodeMirror for the Vim editor implementation
- Marked.js for Markdown parsing
- Material Design Icons for beautiful iconography
- CascadyaCove Nerd Font for editor typography 