from flask import render_template, request, redirect, url_for, flash, jsonify, session
from flask_login import login_user, logout_user, current_user, login_required
from app import db
from app.models.user import User
from app.auth import bp
from app.auth.forms import LoginForm, SignupForm
from app.models.document import Category
from urllib.parse import urlparse

@bp.route('/login', methods=['GET', 'POST'])
def login():
    if current_user.is_authenticated:
        return redirect(url_for('main.index'))
    
    form = LoginForm()
    if form.validate_on_submit():
        user = User.query.filter_by(username=form.username.data).first()
        if user is None or not user.check_password(form.password.data):
            flash('Invalid username or password', 'error')
            return redirect(url_for('auth.login'))
        
        login_user(user, remember=form.remember_me.data)
        session.permanent = True
        
        next_page = request.args.get('next')
        if not next_page or urlparse(next_page).netloc != '':
            next_page = url_for('main.index')
        
        return redirect(next_page)
    
    return render_template('auth/login.html', title='Sign In', form=form)

@bp.route('/signup', methods=['GET', 'POST'])
def signup():
    if current_user.is_authenticated:
        return redirect(url_for('main.index'))
    
    form = SignupForm()
    if form.validate_on_submit():
        user = User(username=form.username.data)
        user.set_password(form.password.data)
        
        db.session.add(user)
        db.session.flush()  # Get the user ID for the next step
        
        # Create root category for the user
        root_category = Category(
            name='',  # Empty name for the root
            icon='mdi-folder-outline',
            description='Default container for documents and categories',
            user_id=user.id,
            is_root=True
        )
        db.session.add(root_category)
        db.session.commit()
        
        flash('Your account has been created!', 'success')
        login_user(user)
        return redirect(url_for('main.index'))
    
    return render_template('auth/signup.html', title='Sign Up', form=form)

@bp.route('/logout')
def logout():
    logout_user()
    return redirect(url_for('auth.login'))

@bp.route('/settings', methods=['GET', 'POST'])
@login_required
def settings():
    if request.method == 'POST':
        if 'theme_color' in request.form:
            current_user.theme_color = request.form['theme_color']
            db.session.commit()
            flash('Settings updated!', 'success')
    
    return render_template('auth/settings.html', title='Settings') 